-- EyeFiDatabase tables for Android

-- Upload tracking tables - start
-- Note, _id is a typical usage for android so I followed their naming.
--
create table if not exists uploadTracking
{
    _id             integer             primary key autoincrement,      -- autoincrement
    fileid          integer             not null,                       -- encoded file id for this entry
    profileid       integer             not null,                       -- which online profile was last used
    uploaded        integer             not null,                       -- whether uploaded successfully. Is set after all profiles that have been selected have completed uploading
    upload_date     integer             not null,                       -- when this file was last uploaded
    status          integer             not null,                       -- is this file in an error condition or not?
    last_attempt    datetime            not null,                       -- last upload attempt
    media_type      integer             not null,                       -- 1 == jpg, 2 == video, 4 == raw
    flags           integer default '0' not null,                       -- flags which indicate whether the file should be stored in Eye-Fi View or downsynced to a computer
    last_signature  varchar(32)         null,                           -- signature by which this file is identifiable on the server
    last_mac        varchar(17)         null                            -- mac which uploaded this file
};

create table if not exists uploadFileList
{
    _id              integer                primary key autoincrement,  -- autoincrement
    fileid           integer                not null,                   -- encoded file id for this entry
    profileid        integer                not null,                   -- which online profile to use (if any)
    uploaded         integer                not null,                   -- whether uploaded successfully
    event_log_path   varchar(255),                                      -- where the event log for this job resides
    retry_count      integer default '0'    not null,                   -- how many times this job has tried to execute
    signature        char(32),                                          -- signature used to identify upsyncs
    mac              char(17),                                          -- mac used for upsyncs
    tar_size         integer,                                           -- size used for upsyncs
    priority         integer default '-1'   null,                       -- -1 == exclude 0 == upsync, 1 == device-initiated, 2 == user-initiated 3 == geo
    type             integer default '-1'   null,                       -- 0 == upsync, 1 == device-initiated, 2 == user-initiated 3 == geo
    payload          varchar(255)                                       -- useful for any additional info which needs to be added to the job. Example being the query string parameter to pass for the Preferences array to the photos.publish.service API call.
};

create table if not exists deviceTable 
{
    _id             integer             primary key autoincrement,
    mac             varchar(255)        not null,
    device_name     varchar(255)        not null,
    mode            integer             not null,
    timestamp       integer             not null,
    upload_policy   integer             not null,
    desktop_id      varchar(255)        not null,
    upload_assist   varchar(255)        not null,
    brand           varchar(255)        not null,
    type            integer             not null,
    upload_key      varchar(255)        not null,
    downsync_key    varchar(255)        not null,
    endless_mem     integer             not null,
    feature_geotag  integer             not null
};

create table if not exists profileInfo
{
    _id                     integer         primary key autoincrement,
    profileName             varchar(100)    not null,
    profileId               integer         not null,
    profile_privacy         varchar(255),
    supportedMediaType      integer         not null,
    url                     varchar(255)
};

create table if not exists deviceUploads
{
    _id          integer         primary key autoincrement,         -- autoincrement
    filename     varchar(255)    not null,                          -- name of the incoming file
    signature    char(32)        not null,                          -- incoming file's signature
    mac          char(17)        not null,                          -- mac where the file originated
    size         integer,                                           -- size of the tar archive
    sync_status  integer,                                           -- agent reported sync status
    flags        integer,                                           -- flags retrieved from the upload
    transfer_start_time         timestamp not null default CURRENT_TIMESTAMP    -- when this upload was started
};
